@@ -5,7 +5,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"io/ioutil"
-	"net"
 	"os"
 
 	igntypes "github.com/coreos/ignition/config/v2_2/types"
@@ -126,12 +125,22 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 		}
 	}
 
+	machineV4CIDRs, machineV6CIDRs := []string{}, []string{}
+	for _, network := range installConfig.Config.Networking.MachineNetwork {
+		if network.CIDR.IPNet.IP.To4() != nil {
+			machineV4CIDRs = append(machineV4CIDRs, network.CIDR.IPNet.String())
+		} else {
+			machineV6CIDRs = append(machineV6CIDRs, network.CIDR.IPNet.String())
+		}
+	}
+
 	masterCount := len(mastersAsset.MachineFiles)
 	data, err := tfvars.TFVars(
 		clusterID.InfraID,
 		installConfig.Config.ClusterDomain(),
 		installConfig.Config.BaseDomain,
-		&installConfig.Config.Networking.MachineNetwork[0].CIDR.IPNet,
+		machineV4CIDRs,
+		machineV6CIDRs,
 		useIPv4,
 		useIPv6,
 		bootstrapIgn,
@@ -235,18 +244,6 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 			workerConfigs[i] = w.Spec.Template.Spec.ProviderSpec.Value.Object.(*azureprovider.AzureMachineProviderSpec)
 		}
 
-		var (
-			machineV4CIDRs []net.IPNet
-			machineV6CIDRs []net.IPNet
-		)
-		for _, network := range installConfig.Config.Networking.MachineNetwork {
-			if network.CIDR.IPNet.IP.To4() != nil {
-				machineV4CIDRs = append(machineV4CIDRs, network.CIDR.IPNet)
-			} else {
-				machineV6CIDRs = append(machineV6CIDRs, network.CIDR.IPNet)
-			}
-		}
-
 		preexistingnetwork := installConfig.Config.Azure.VirtualNetwork != ""
 		data, err := azuretfvars.TFVars(
 			azuretfvars.TFVarsSources{
@@ -257,8 +254,6 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 				ImageURL:                    string(*rhcosImage),
 				PreexistingNetwork:          preexistingnetwork,
 				Publish:                     installConfig.Config.Publish,
-				MachineV4CIDRs:              machineV4CIDRs,
-				MachineV6CIDRs:              machineV6CIDRs,
 			},
 		)
 		if err != nil {
@@ -414,6 +409,25 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 		if err != nil {
 			return err
 		}
+		con, err := ovirtconfig.NewConnection()
+		if err != nil {
+			return err
+		}
+		defer con.Close()
+
+		if installConfig.Config.Platform.Ovirt.VNICProfileID == "" {
+			profiles, err := ovirtconfig.FetchVNICProfileByClusterNetwork(
+				con,
+				installConfig.Config.Platform.Ovirt.ClusterID,
+				installConfig.Config.Platform.Ovirt.NetworkName)
+			if err != nil {
+				return errors.Wrapf(err, "failed to compute values for oVirt platform")
+			}
+			if len(profiles) != 1 {
+				return errors.Wrapf(err, "failed to compute values for oVirt platform, there are multiple vNic profiles.")
+			}
+			installConfig.Config.Platform.Ovirt.VNICProfileID = profiles[0].MustId()
+		}
 
 		data, err := ovirttfvars.TFVars(
 			config.URL,
@@ -423,6 +437,7 @@ func (t *TerraformVariables) Generate(parents asset.Parents) error {
 			installConfig.Config.Platform.Ovirt.ClusterID,
 			installConfig.Config.Platform.Ovirt.StorageDomainID,
 			installConfig.Config.Platform.Ovirt.NetworkName,
+			installConfig.Config.Platform.Ovirt.VNICProfileID,
 			string(*rhcosImage),
 			clusterID.InfraID,
 		)
